@@ -1,28 +1,39 @@
 from fastapi_helpers.workers import Worker
-from fastapi_helpers.logging import (
+from fastapi_helpers.core.logging import (
     get_logger_default_config,
     get_machine_name,
     get_stream_name,
     get_logger_prod_config,
 )
-from fastapi_helpers.middlewares import(
+from fastapi_helpers.routes.middlewares import(
     get_real_ip,
     get_real_ip_from_headers,
     HeadersMiddleware,
 )
 from fastapi_helpers.routes import (
-    DefaultModelRouter,
     load_data_callback,
-    Pagination,
     paginate_object
 )
+from fastapi_helpers.routes.routers import (
+   DefaultModelRouter,
+   get_router
+)
+from fastapi_helpers.routes.models import (
+    PaginateOptions,
+    PaginateResult,
+)
+
+from fastapi_helpers.routes.models import (
+    PaginateOptions,
+    PaginateResult,
+)
 from fastapi_helpers.crud import BaseCrud, to_dict
 from fastapi_helpers.security import Encoder
-from fastapi_helpers.settings import DefaultSettings
+from fastapi_helpers.core.settings import DefaultSettings
 from fastapi_helpers.db import DbConfig
 from fastapi_helpers.db.seeders import DbSeeder
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 
 __all__ = [
     "get_logger_default_config",
@@ -42,5 +53,8 @@ __all__ = [
     "BaseCrud",
     "to_dict",
     "Encoder",
-    "DefaultSettings"
+    "DefaultSettings",
+    "PaginateOptions",
+    "PaginateResult",
+    "get_router"
 ]
