@@ -1,20 +1,36 @@
 from ormar import Model
-from fastapi_helpers.routes.Paginate import paginate_object, load_data_callback, Pagination
-from typing import Any, List, Type, Optional, Dict, Union
+from fastapi_helpers.routes.models import PaginateOptions, PaginateResult
+from fastapi_helpers.routes.Paginate import paginate_object, load_data_callback
+from typing import (
+    List, Type, Optional, Dict, TypeVar, Union,
+    Generic
+)
 
 
-class BaseCrud():
+T = TypeVar('T', bound=Model)
+
+
+class BaseCrud(Generic[T]):
 
     search_attrs = []
 
-    def __init__(self, model: Type[Model]) -> None:
+    def __init__(
+        self,
+        model: Type[T]
+    ) -> None:
         self.model = model
 
-    async def load_data(self, result:List[Model] =[]) -> List[Model]:
+    async def load_data(
+        self,
+        result: List[T] = []
+    ) -> List[T]:
         return await load_data_callback(result)
 
-    async def get_list(self, options: Pagination) -> List[Any]:
-        if(options.search == ''):
+    async def get_list(
+        self,
+        options: PaginateOptions
+    ) -> Union[List[T], PaginateResult[T]]:
+        if(options.filters == ''):
             r = await paginate_object(
                 self.model,
                 options,
@@ -24,10 +40,13 @@ class BaseCrud():
         else:
             return await self.search(options)
 
-    async def search(self, options: Pagination):
+    async def search(
+        self,
+        options: PaginateOptions
+    ) -> Union[List[T], PaginateResult[T]]:
         searchable = {}
         for item in self.search_attrs:
-            searchable[item + "__icontains"] = options.search
+            searchable[item + "__icontains"] = options.filters
         options.orable = searchable
         return await paginate_object(
             self.model,
@@ -35,8 +54,11 @@ class BaseCrud():
             (self.load_data, {})
         )
 
-    async def get(self, id: Optional[Union[int, str]]) -> Union[Optional[Model] , Dict]:
-        options = Pagination()
+    async def get(
+        self,
+        id: Union[int, str]
+    ) -> Union[T, Dict]:
+        options = PaginateOptions()
         options.limit = 1
         options.filters = {'id': id}
         objs = await paginate_object(
@@ -48,12 +70,18 @@ class BaseCrud():
             return objs[0]
         return None
 
-    async def get_or_create(self, model_in: Optional[Union[Dict, Model]]) -> Optional[Model]:
+    async def get_or_create(
+        self,
+        model_in: Union[T, Dict]
+    ) -> Union[T, Dict]:
         params = to_dict(model_in)
         obj = await self.model.objects.get_or_create(**params)
         return obj
 
-    async def create(self, model_in: Optional[Union[Dict, Model]]) -> Optional[Model]:
+    async def create(
+        self,
+        model_in: Union[T, Dict]
+    ) -> Optional[Union[T, Dict]]:
         params = to_dict(model_in)
         obj = self.model(**params)
         obj = await obj.save()
@@ -62,8 +90,8 @@ class BaseCrud():
     async def update(
         self,
         id: Optional[Union[int, str]],
-        model_in: Optional[Union[Dict, Model]]
-    ) -> Optional[Model]:
+        model_in: Union[T, Dict]
+    ) -> Optional[Union[T, Dict]]:
         params = to_dict(model_in)
         obj = await self.model.objects.get_or_none(id=id)
         if(obj is None):
@@ -71,7 +99,10 @@ class BaseCrud():
         obj = await obj.update(**params)
         return obj
 
-    async def delete(self, id: Optional[Union[int, str]]) -> Optional[Model]:
+    async def delete(
+        self,
+        id: Optional[Union[int, str]]
+    ) -> Optional[Union[T, Dict]]:
         obj = await self.model.objects.get_or_none(id=id)
         if(obj is None):
             return None
@@ -79,7 +110,10 @@ class BaseCrud():
         return obj
 
 
-def to_dict(model_in):
+def to_dict(
+    model_in: 
+    Union[T, Dict]
+) -> Dict:
     params = {}
     if isinstance(model_in, dict):
         params = model_in
